@@ -164,9 +164,13 @@ class MAX31856:
 
     @property
     def temperature(self):
-        """The temperature of the sensor and return its value in degrees Celsius. (read-only)"""
+        """Measure the temperature of the sensor and wait for the result.
+        Return value is in degrees Celsius. (read-only)"""
         self._perform_one_shot_measurement()
+        return self.unpack_temperature()
 
+    def unpack_temperature(self) -> float:
+        """Reads the probe temperature from the register"""
         # unpack the 3-byte temperature as 4 bytes
         raw_temp = unpack(
             ">i", self._read_register(_MAX31856_LTCBH_REG, 3) + bytes([0])
@@ -182,9 +186,12 @@ class MAX31856:
 
     @property
     def reference_temperature(self):
-        """The temperature of the cold junction in degrees Celsius. (read-only)"""
+        """Wait to retreive temperature of the cold junction in degrees Celsius. (read-only)"""
         self._perform_one_shot_measurement()
+        return self.unpack_reference_temperature()
 
+    def unpack_reference_temperature(self) -> float:
+        """Reads the reference temperature from the register"""
         raw_read = unpack(">h", self._read_register(_MAX31856_CJTH_REG, 2))[0]
 
         # effectively shift raw_read >> 8 to convert pseudo-float
@@ -264,8 +271,16 @@ class MAX31856:
         }
 
     def _perform_one_shot_measurement(self):
+        self.initiate_one_shot_measurement()
+        # wait for the measurement to complete
+        self._wait_for_oneshot()
 
-        self._write_u8(_MAX31856_CJTO_REG, 0x0)
+    def initiate_one_shot_measurement(self):
+        """Starts a one-shot measurement and returns immediately.
+        A measurement takes approximately 160ms.
+        Check the status of the measurement with `oneshot_pending`; when it is false,
+        the measurement is complete and the value can be read with `unpack_temperature`.
+        """
         # read the current value of the first config register
         conf_reg_0 = self._read_register(_MAX31856_CR0_REG, 1)[0]
 
@@ -277,7 +292,19 @@ class MAX31856:
         # write it back with the new values, prompting the sensor to perform a measurement
         self._write_u8(_MAX31856_CR0_REG, conf_reg_0)
 
-        sleep(0.250)
+    @property
+    def oneshot_pending(self) -> bool:
+        """A boolean indicating the status of the one-shot flag.
+        A True value means the measurement is still ongoing.
+        A False value means measurement is complete."""
+        oneshot_flag = (
+            self._read_register(_MAX31856_CR0_REG, 1)[0] & _MAX31856_CR0_1SHOT
+        )
+        return bool(oneshot_flag)
+
+    def _wait_for_oneshot(self):
+        while self.oneshot_pending:
+            sleep(0.01)
 
     def _read_register(self, address, length):
         # pylint: disable=no-member
